@@ -1,9 +1,14 @@
-#!/usr/local/bin/perl
-
 use Config;
+use Cwd 'abs_path';
 
 # Run and check all the tests
 
+if (!-t) {
+  # STDIN not tty = not interactive, can't run tests
+  print "STDIN not tty = not interactive, can't run tests\n";
+  exit 0;
+}
+
 $| = 1; # Unbuffer STDOUT
 
 # Stop f77-linking causing spurious undefined symbols (alpha)
@@ -35,7 +40,7 @@ foreach $jjj (1..12) {
 
    print "============== Running test$jjj.p ==============\n";
    %@ = ();       # Clear error status
-   do "./test$jjj.p";
+   do(abs_path("test$jjj.p"));
    warn $@ if $@; # Report any error detected
    if($dev eq '/PNG' && $^O =~ /mswin32/i) {
      system("ren pgplot.png pgplot_$jjj.png");
